_common library
Classes
- BaseModel
- DataRefModel
-
Generated class for
_DataRefModel. - DataRefModelFieldNames
- FieldModel
-
Generated class for
_FieldModel. - FieldModelFieldNames
- FieldTypes
-
Catalogue of prefix-vocabulary
fieldTypestrings recognised by the generator's mapper composition. Use these constants instead of raw string literals — typos turn into compile errors, and IDE autocomplete shows the full menu of dialect/type combinations. - FieldUtils
- GenerateDartModel
-
Generated class for
_GenerateDartModel. - GenerateDartModelFieldNames
- Model
- ReferencedModel
-
Generated class for
_ReferencedModel. - ReferencedModelFieldNames
-
ThisModel<
T extends BaseModel> - A class that extends BaseModel that provides a reference to itself.
Mixins
-
ReferencedModelEqualityMixin<
T extends ReferencedModel> - A mixin on ReferencedModel that implements EquatableMixin to identify the model by id an ref.
-
ThisModelMixin<
T extends BaseModel> - A mixin on BaseModel that provides a reference to itself.
Extensions
Constants
-
DATA_REF_FIELDS
→ const Set<
FieldModel> -
FIELD_MODEL_FIELDS
→ const Set<
FieldModel> -
GENERATE_DART_MODEL_FIELDS
→ const Set<
FieldModel> -
REFERENCED_MODEL_FIELDS
→ const Set<
FieldModel> - T_CAMEL_CASE_STRING → const String
- T_LOWER_CASE_STRING → const String
- T_LOWER_KEBAB_CASE_STRING → const String
- T_LOWER_SNAKE_CASE_STRING → const String
- T_NO_SPACES_STRING → const String
- T_PASCAL_CASE_STRING → const String
- T_SEARCHABLE_STRING → const String
- T_TRIMMED_CAMEL_CASE_STRING → const String
- T_TRIMMED_LOWER_CASE_STRING → const String
- T_TRIMMED_LOWER_KEBAB_CASE_STRING → const String
- T_TRIMMED_LOWER_SNAKE_CASE_STRING → const String
- T_TRIMMED_PASCAL_CASE_STRING → const String
- T_TRIMMED_STRING → const String
- T_TRIMMED_UPPER_CASE_STRING → const String
- T_TRIMMED_UPPER_KEBAB_CASE_STRING → const String
- T_TRIMMED_UPPER_SNAKE_CASE_STRING → const String
- T_UPPER_CASE_STRING → const String
- T_UPPER_KEBAB_CASE_STRING → const String
- T_UPPER_SNAKE_CASE_STRING → const String
Functions
-
dataRefFromString(
String? input) → DataRefModel? - Creates a DataRefModel from a given path string. If the path ends with a '/', it represents a collection path, otherwise, it represents a document path.
-
uniqueRefs<
T extends ReferencedModel> (Iterable< T> input) → Iterable<T> -
Returns a list of unique ReferencedModels from
input. Uniqueness is determined by the ReferencedModel.ref property.
Typedefs
- DataRef = DataRefModel
- Field = FieldModel
-
TFieldRecord
= ({List<
Map< ? children, String? description, Object? fieldPath, String? fieldType, bool? foreignKey, bool? nullable, bool? primaryKey, Object? references})String, dynamic> > - A record representing a field. Similar to FieldModel.